@@ -288,7 +288,7 @@ def serve(args, config_dir=None):
                 if path.strip() == '/':
                     routes_config['/'].update(section['/'])
                 else:
-                    routes_config.update(section[path])
+                    routes_config[path] = section[path].copy()
             app_config = config.app_config.copy()
             app_config.pop("controllers")
             routes_config.update(app_config)
