@@ -1,6 +1,7 @@
 import copy
 import hashlib
 import hmac
+import textwrap
 import warnings
 
 from base64 import b64encode, urlsafe_b64encode
@@ -13,7 +14,13 @@ except ImportError:
 from datetime import date, time, datetime, timedelta
 
 from dateutil.parser import parse as parse_date
-from sqlalchemy.orm import RelationshipProperty, Session, collections
+
+try:
+    from sqlalchemy.orm import RelationshipProperty, Session, collections
+except ImportError:
+    sqlalchemy_support = False
+else:
+    sqlalchemy_support = True
 
 try:
     from geoalchemy.base import SpatialElement, WKTSpatialElement
@@ -30,15 +37,16 @@ __all__ = ["to_collection", "to_mapping", "from_mapping", "CSRFToken",
            "pad_block_cipher_message", "unpad_block_cipher_message"]
 
 
-def _get_model_properties(model, excludes):
+def _get_model_properties(model, excludes, recursive=False):
     props = {}
     for prop in model.__mapper__.iterate_properties:
         if isinstance(prop, RelationshipProperty):
-            props[prop.key] = prop
-            if prop.backref:
-                backref_prop_key = prop.backref[0]
-                for mapper in prop.mapper.polymorphic_iterator():
-                    excludes.setdefault(mapper.class_, set()).add(backref_prop_key)
+            if recursive:
+                props[prop.key] = prop
+                if prop.backref:
+                    backref_prop_key = prop.backref[0]
+                    for mapper in prop.mapper.polymorphic_iterator():
+                        excludes.setdefault(mapper.class_, set()).add(backref_prop_key)
         else:
             if prop.key.startswith("_"):
                 props[prop.columns[0].key] = prop
@@ -157,10 +165,18 @@ def to_collection(from_, includes=None, excludes=None, format=None, recursive=Fa
     """
     if hasattr(from_, "__mapper__"):
 
+        if not sqlalchemy_support:
+            raise ImportError(textwrap.dedent("""SQLAlchemy not installed.
+
+            Please use install it first before proceding:
+
+            $ pip install sqlalchemy
+            """))
+
         includes = _ensure_is_dict(from_.__class__, includes)
         excludes = _ensure_is_dict(from_.__class__, excludes)
 
-        props = _get_model_properties(from_, excludes)
+        props = _get_model_properties(from_, excludes, recursive=recursive)
         attrs = set(props.iterkeys())
         if includes and from_.__class__ in includes:
             attrs |= includes[from_.__class__]
@@ -278,7 +294,16 @@ def from_collection(from_, to_, excludes=None, format=None, collection_handling=
                 if k in from_:
                     to_[k] = from_collection(from_[k], to_[k], excludes=excludes)
         elif hasattr(to_, "__mapper__"):
-            props = _get_model_properties(to_, excludes)
+
+            if not sqlalchemy_support:
+                raise ImportError(textwrap.dedent("""SQLAlchemy not installed.
+    
+                Please use install it first before proceding:
+    
+                $ pip install sqlalchemy
+                """))
+
+            props = _get_model_properties(to_, excludes, recursive=True)
             attrs = set(props.iterkeys())
             if excludes and to_.__class__ in excludes:
                 attrs -= excludes[to_.__class__]
@@ -305,7 +330,7 @@ def from_collection(from_, to_, excludes=None, format=None, collection_handling=
                             for v in from_iterator:
                                 prop_inst = _get_property_instance(Session.object_session(to_), v, prop)
                                 appender(from_collection(v, prop_inst, excludes=excludes))
-                            
+
                             if collection_handling == "replace":
                                 setattr(to_, attr, col)
                         else:
